package xyz.lychee.lagfixer.utils;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;

public final class ZipUtils {
   private static final int BUFFER_LEN = 8192;

   private ZipUtils() {
      throw new UnsupportedOperationException("u can't instantiate me...");
   }

   public static boolean zipFiles(Collection<String> srcFiles, String zipFilePath) throws IOException {
      return zipFiles(srcFiles, (String)zipFilePath, (String)null);
   }

   public static boolean zipFiles(Collection<String> srcFilePaths, String zipFilePath, String comment) throws IOException {
      if (srcFilePaths != null && zipFilePath != null) {
         ZipOutputStream zos = null;

         boolean var6;
         try {
            zos = new ZipOutputStream(Files.newOutputStream(Paths.get(zipFilePath)));
            Iterator var4 = srcFilePaths.iterator();

            String srcFile;
            do {
               if (!var4.hasNext()) {
                  boolean var10 = true;
                  return var10;
               }

               srcFile = (String)var4.next();
            } while(zipFile(new File(srcFile), "", zos, comment));

            var6 = false;
         } finally {
            if (zos != null) {
               zos.finish();
               zos.close();
            }

         }

         return var6;
      } else {
         return false;
      }
   }

   public static boolean zipFiles(Collection<File> srcFiles, File zipFile) throws IOException {
      return zipFiles(srcFiles, (File)zipFile, (String)null);
   }

   public static boolean zipFiles(Collection<File> srcFiles, File zipFile, String comment) throws IOException {
      if (srcFiles != null && zipFile != null) {
         ZipOutputStream zos = null;

         boolean var10;
         try {
            zos = new ZipOutputStream(Files.newOutputStream(zipFile.toPath()));
            Iterator var4 = srcFiles.iterator();

            while(var4.hasNext()) {
               File srcFile = (File)var4.next();
               if (!zipFile(srcFile, "", zos, comment)) {
                  boolean var6 = false;
                  return var6;
               }
            }

            var10 = true;
         } finally {
            if (zos != null) {
               zos.finish();
               zos.close();
            }

         }

         return var10;
      } else {
         return false;
      }
   }

   public static boolean zipFile(String srcFilePath, String zipFilePath) throws IOException {
      return zipFile((File)(new File(srcFilePath)), (File)(new File(zipFilePath)), (String)null);
   }

   public static boolean zipFile(String srcFilePath, String zipFilePath, String comment) throws IOException {
      return zipFile(new File(srcFilePath), new File(zipFilePath), comment);
   }

   public static boolean zipFile(File srcFile, File zipFile) throws IOException {
      return zipFile((File)srcFile, (File)zipFile, (String)null);
   }

   public static boolean zipFile(File srcFile, File zipFile, String comment) throws IOException {
      if (srcFile != null && zipFile != null) {
         ZipOutputStream zos = new ZipOutputStream(Files.newOutputStream(zipFile.toPath()));

         boolean var4;
         try {
            var4 = zipFile(srcFile, "", zos, comment);
         } catch (Throwable var7) {
            try {
               zos.close();
            } catch (Throwable var6) {
               var7.addSuppressed(var6);
            }

            throw var7;
         }

         zos.close();
         return var4;
      } else {
         return false;
      }
   }

   private static boolean zipFile(File srcFile, String rootPath, ZipOutputStream zos, String comment) throws IOException {
      rootPath = rootPath + (rootPath.contentEquals(" ") ? "" : File.separator) + srcFile.getName();
      ZipEntry entry;
      int len;
      if (srcFile.isDirectory()) {
         File[] fileList = srcFile.listFiles();
         if (fileList != null && fileList.length > 0) {
            File[] var12 = fileList;
            int var6 = fileList.length;

            for(len = 0; len < var6; ++len) {
               File file = var12[len];
               if (!zipFile(file, rootPath, zos, comment)) {
                  return false;
               }
            }
         } else {
            entry = new ZipEntry(rootPath + '/');
            entry.setComment(comment);
            zos.putNextEntry(entry);
            zos.closeEntry();
         }
      } else {
         InputStream is = new BufferedInputStream(Files.newInputStream(srcFile.toPath()));

         try {
            entry = new ZipEntry(rootPath);
            entry.setComment(comment);
            zos.putNextEntry(entry);
            byte[] buffer = new byte[8192];

            while(true) {
               if ((len = is.read(buffer, 0, 8192)) == -1) {
                  zos.closeEntry();
                  break;
               }

               zos.write(buffer, 0, len);
            }
         } catch (Throwable var10) {
            try {
               is.close();
            } catch (Throwable var9) {
               var10.addSuppressed(var9);
            }

            throw var10;
         }

         is.close();
      }

      return true;
   }

   public static List<File> unzipFile(String zipFilePath, String destDirPath) throws IOException {
      return unzipFileByKeyword((String)zipFilePath, (String)destDirPath, (String)null);
   }

   public static List<File> unzipFile(File zipFile, File destDir) throws IOException {
      return unzipFileByKeyword((File)zipFile, (File)destDir, (String)null);
   }

   public static List<File> unzipFileByKeyword(String zipFilePath, String destDirPath, String keyword) throws IOException {
      return unzipFileByKeyword(new File(zipFilePath), new File(destDirPath), keyword);
   }

   public static List<File> unzipFileByKeyword(File zipFile, File destDir, String keyword) throws IOException {
      if (zipFile != null && destDir != null) {
         List<File> files = new ArrayList();
         ZipFile zip = new ZipFile(zipFile);
         Enumeration<?> entries = zip.entries();

         try {
            ZipEntry entry;
            String entryName;
            ArrayList var8;
            if (keyword.contentEquals(" ")) {
               while(entries.hasMoreElements()) {
                  entry = (ZipEntry)entries.nextElement();
                  entryName = entry.getName().replace("\\", "/");
                  if (!entryName.contains("../") && !unzipChildFile(destDir, files, zip, entry, entryName)) {
                     var8 = files;
                     return var8;
                  }
               }
            } else {
               while(entries.hasMoreElements()) {
                  entry = (ZipEntry)entries.nextElement();
                  entryName = entry.getName().replace("\\", "/");
                  if (!entryName.contains("../") && entryName.contains(keyword) && !unzipChildFile(destDir, files, zip, entry, entryName)) {
                     var8 = files;
                     return var8;
                  }
               }
            }
         } finally {
            zip.close();
         }

         return files;
      } else {
         return null;
      }
   }

   private static boolean unzipChildFile(File destDir, List<File> files, ZipFile zip, ZipEntry entry, String name) throws IOException {
      File file = new File(destDir, name);
      files.add(file);
      if (entry.isDirectory()) {
         return file.mkdirs();
      } else if (!file.createNewFile()) {
         return false;
      } else {
         InputStream in = new BufferedInputStream(zip.getInputStream(entry));

         try {
            OutputStream out = new BufferedOutputStream(Files.newOutputStream(file.toPath()));

            try {
               byte[] buffer = new byte[8192];

               int len;
               while((len = in.read(buffer)) != -1) {
                  out.write(buffer, 0, len);
               }
            } catch (Throwable var12) {
               try {
                  out.close();
               } catch (Throwable var11) {
                  var12.addSuppressed(var11);
               }

               throw var12;
            }

            out.close();
         } catch (Throwable var13) {
            try {
               in.close();
            } catch (Throwable var10) {
               var13.addSuppressed(var10);
            }

            throw var13;
         }

         in.close();
         return true;
      }
   }

   public static List<String> getFilesPath(String zipFilePath) throws IOException {
      return getFilesPath(new File(zipFilePath));
   }

   public static List<String> getFilesPath(File zipFile) throws IOException {
      if (zipFile == null) {
         return null;
      } else {
         List<String> paths = new ArrayList();
         ZipFile zip = new ZipFile(zipFile);
         Enumeration<?> entries = zip.entries();

         while(entries.hasMoreElements()) {
            String entryName = ((ZipEntry)entries.nextElement()).getName().replace("\\", "/");
            if (entryName.contains("../")) {
               paths.add(entryName);
            } else {
               paths.add(entryName);
            }
         }

         zip.close();
         return paths;
      }
   }

   public static List<String> getComments(String zipFilePath) throws IOException {
      return getComments(new File(zipFilePath));
   }

   public static List<String> getComments(File zipFile) throws IOException {
      if (zipFile == null) {
         return null;
      } else {
         List<String> comments = new ArrayList();
         ZipFile zip = new ZipFile(zipFile);
         Enumeration<?> entries = zip.entries();

         while(entries.hasMoreElements()) {
            ZipEntry entry = (ZipEntry)entries.nextElement();
            comments.add(entry.getComment());
         }

         zip.close();
         return comments;
      }
   }
}
